@@ -1036,10 +1036,10 @@ decode_notification_ind (struct wsp_header_iter *iter,
                          struct mms_message     *out)
 {
   return mms_parse_headers (iter, MMS_HEADER_TRANSACTION_ID,
-                            HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                            HEADER_FLAG_MANDATORY,
                             &out->transaction_id,
                             MMS_HEADER_MMS_VERSION,
-                            HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                            HEADER_FLAG_MANDATORY,
                             &out->version,
                             MMS_HEADER_FROM,
                             0, &out->ni.from,
@@ -1235,9 +1235,9 @@ decode_retrieve_conf (struct wsp_header_iter *iter,
                       struct mms_message     *out)
 {
   if (mms_parse_headers (iter, MMS_HEADER_TRANSACTION_ID,
-                         HEADER_FLAG_PRESET_POS, &out->transaction_id,
+                         0, &out->transaction_id,
                          MMS_HEADER_MMS_VERSION,
-                         HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                         HEADER_FLAG_MANDATORY,
                          &out->version,
                          MMS_HEADER_FROM,
                          0, &out->rc.from,
@@ -1276,10 +1276,10 @@ decode_send_conf (struct wsp_header_iter *iter,
                   struct mms_message     *out)
 {
   return mms_parse_headers (iter, MMS_HEADER_TRANSACTION_ID,
-                            HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                            HEADER_FLAG_MANDATORY,
                             &out->transaction_id,
                             MMS_HEADER_MMS_VERSION,
-                            HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                            HEADER_FLAG_MANDATORY,
                             &out->version,
                             MMS_HEADER_RESPONSE_STATUS,
                             HEADER_FLAG_MANDATORY, &out->sc.rsp_status,
@@ -1293,10 +1293,10 @@ decode_send_req (struct wsp_header_iter *iter,
                  struct mms_message     *out)
 {
   if (mms_parse_headers (iter, MMS_HEADER_TRANSACTION_ID,
-                         HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                         HEADER_FLAG_MANDATORY,
                          &out->transaction_id,
                          MMS_HEADER_MMS_VERSION,
-                         HEADER_FLAG_MANDATORY | HEADER_FLAG_PRESET_POS,
+                         HEADER_FLAG_MANDATORY,
                          &out->version,
                          MMS_HEADER_TO,
                          HEADER_FLAG_ALLOW_MULTI, &out->sr.to,
