@@ -720,6 +720,14 @@ static const unsigned char mms_m_send_conf_2[] = {
  */
 static const char mms_delivery_ind_1[] = "./unit/di-mms-1.mms";
 
+/*
+ * MMS post_rsp PDU 1
+ * This PDU is a post response
+ * MMS message type: post-rsp
+ * MMS version: 1.2
+ */
+static const char mms_post_rsp_1[] = "./unit/post-rsp.johnwa.mms";
+
 struct mms_test
 {
   const char *pathname;
@@ -830,6 +838,10 @@ static const struct mms_test mms_delivery_ind_test_1 = {
   .pathname = mms_delivery_ind_1,
 };
 
+static const struct mms_test mms_post_rsp_test_1 = {
+  .pathname = mms_post_rsp_1,
+};
+
 static void
 test_decode_mms (gconstpointer data)
 {
@@ -1099,6 +1111,9 @@ main (int    argc,
   g_test_add_data_func ("/mmsutil/Decode MMS Delivery Indication PDU 1",
                         &mms_delivery_ind_test_1, test_decode_mms);
 
+  g_test_add_data_func ("/mmsutil/Decode MMS Post Response PDU 1",
+                        &mms_post_rsp_test_1, test_decode_mms);
+
   g_test_add_data_func ("/mmsutil/Decode MMS M-Send.Conf PDU 1",
                         &mms_m_send_conf_test_1, test_decode_mms);
   g_test_add_data_func ("/mmsutil/Decode MMS M-Send.Conf PDU 2",
